==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiGui/QAccessibleActionInterface_shell.h <==
#ifndef QACCESSIBLEACTIONINTERFACE_IMPL_SHELL_H
#define QACCESSIBLEACTIONINTERFACE_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtGui/qaccessible.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtJambi/RegistryAPI>


class QAccessibleActionInterface_shell : public QAccessibleActionInterface, public QtJambiShellInterface
{
public:
    QAccessibleActionInterface_shell();
    ~QAccessibleActionInterface_shell() override;

    QStringList actionNames() const override;
    void doAction(const QString& actionName0) override;
    QStringList keyBindingsForAction(const QString& actionName0) const override;
    QString localizedActionDescription(const QString& name0) const override;
    QString localizedActionName(const QString& name0) const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAccessibleActionInterface_access : public QAccessibleActionInterface
{
    jobject __qt_actionNames(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_doAction_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring actionName0);
    jobject __qt_keyBindingsForAction_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring actionName0) const;
    jstring __qt_localizedActionDescription_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jstring __qt_localizedActionName_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
};

#endif // QACCESSIBLEACTIONINTERFACE_IMPL_SHELL_H

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QAccessibleActionInterface_shell.h <==
#ifndef QACCESSIBLEACTIONINTERFACE_IMPL_SHELL_H
#define QACCESSIBLEACTIONINTERFACE_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qaccessible.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtJambi/RegistryAPI>


class QAccessibleActionInterface_shell : public QAccessibleActionInterface, public QtJambiShellInterface
{
public:
    QAccessibleActionInterface_shell();
    ~QAccessibleActionInterface_shell() override;

    QStringList actionNames() const override;
    void doAction(const QString& actionName0) override;
    QStringList keyBindingsForAction(const QString& actionName0) const override;
    QString localizedActionDescription(const QString& name0) const override;
    QString localizedActionName(const QString& name0) const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAccessibleActionInterface_access : public QAccessibleActionInterface
{
    jobject __qt_actionNames_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_doAction_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring actionName0);
    jobject __qt_keyBindingsForAction_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring actionName0) const;
    jstring __qt_localizedActionDescription_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jstring __qt_localizedActionName_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
};

#endif // QACCESSIBLEACTIONINTERFACE_IMPL_SHELL_H
